@@ -15,12 +15,11 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ****************************************************************************/
- /* $Id: qgisinterface.cpp 4992 2006-03-10 03:11:06Z g_j_m $ */
+/* $Id: qgisinterface.cpp 9138 2008-08-23 21:37:31Z jef $ */
 
 #include "qgisinterface.h"
-#include "qgisapp.h"
 
-QgisInterface::QgisInterface(QgisApp * _qgis, const char *name):QWidget(_qgis, name)
+QgisInterface::QgisInterface()
 {
 
 
